package org.kaveh.commons.farsi.date;

import java.util.Date;

import org.joda.time.DateTime;
import org.kaveh.commons.farsi.access.JalaliDate;
import org.kaveh.commons.farsi.constatns.FarsiDateConstants;
import org.kaveh.commons.farsi.utils.ConstantReflectionUtilies;
import org.kaveh.commons.farsi.utils.JalaliCalendarUtils;
import org.kaveh.commons.farsi.word.FarsiWord;

/**
 * Jalali Date Class, class to represent Jalali date, supports conversion of
 * gregorian date to jalali and vice versa.
 * 
 * @author Kaveh Ranjbar
 * 
 */
public class JalaliDateImpl implements JalaliDate {

	private int day;
	private int month;
	private int year;

	public JalaliDateImpl(int year, int month, int day) {
		this.year = year;
		this.month = month;
		this.day = day;
	}

	public JalaliDateImpl(DateTime gregorianDateTime) {
		JalaliDate myDate = JalaliCalendarUtils
				.convertGregorianToJalali(gregorianDateTime);
		this.year = myDate.getYear();
		this.month = myDate.getMonth();
		this.day = myDate.getDay();
	}

	public JalaliDateImpl(Date gregorianDate) {
		this(new DateTime(gregorianDate));
	}

	public JalaliDateImpl() {
		this(new DateTime());
	}

	/* (non-Javadoc)
	 * @see org.kaveh.commons.farsi.date.JalaliDate#getDay()
	 */
	public int getDay() {
		return day;
	}

	/* (non-Javadoc)
	 * @see org.kaveh.commons.farsi.date.JalaliDate#getMonth()
	 */
	public int getMonth() {
		return month;
	}

	/* (non-Javadoc)
	 * @see org.kaveh.commons.farsi.date.JalaliDate#getMonthName()
	 */
	public String getMonthName() {
		return ConstantReflectionUtilies.findValueByOrder(month - 1,
				FarsiDateConstants.MonthNames.class);
	}

	/* (non-Javadoc)
	 * @see org.kaveh.commons.farsi.date.JalaliDate#getWeekDay()
	 */
	public int getWeekDay() {
		return JalaliCalendarUtils.getWeekDay(this);
	}

	/* (non-Javadoc)
	 * @see org.kaveh.commons.farsi.date.JalaliDate#getWeekDayName()
	 */
	public String getWeekDayName() {
		return ConstantReflectionUtilies.findValueByOrder(JalaliCalendarUtils
				.getWeekDay(this) - 1, FarsiDateConstants.WeekDays.class);
	}

	/* (non-Javadoc)
	 * @see org.kaveh.commons.farsi.date.JalaliDate#getYear()
	 */
	public int getYear() {
		return year;
	}

	/* (non-Javadoc)
	 * @see org.kaveh.commons.farsi.date.JalaliDate#getGregorianDateTime()
	 */
	public DateTime getGregorianDateTime() {
		return JalaliCalendarUtils.convertJalaliToGregorian(this);
	}

	/* (non-Javadoc)
	 * @see org.kaveh.commons.farsi.date.JalaliDate#getGregorianDate()
	 */
	public Date getGregorianDate() {
		return JalaliCalendarUtils.convertJalaliToGregorian(this).toDate();
	}

	/* (non-Javadoc)
	 * @see org.kaveh.commons.farsi.date.JalaliDate#toString()
	 */
	@Override
	public String toString() {
		return FarsiWord.replaceLatinDigit(getYear() + "/" + getMonth() + "/"
				+ getDay());
	}

}
