package org.kaveh.commons.farsi.v2.impl;

import java.util.HashMap;

public class CharDefenitions {

	
	//REGEXPS
	public static final String FARSI_DIGITS_RANGE = "\u06F0-\u06F9";
	public static final String ARABIC_DIGITS_RANGE = "\u0660-\u0669";
	public static final String LATIN_DIGITS_RANGE = "0-9";
	public static final String FARSI_CHARS_RANGE = "\u0618-\u061B\u0627-\u063A\u0640-\u0642\u0642-\u0649\u06F0-\u06F9\u06A9-\u06AA\u06CC\u066B\u066C\u0651\u0653\u06AF\u0686\u067E\u0698";
	public static final String ARABIC_CHARS_RANGE = "\u0600-\u066D";
	public static final String LATIN_CHARS_RANGE = "A-Za-z0-9";
	public static final String USUAL_TEXT_ADDITIONS_RANGE = "\\s\\n\\r\\.|?|!|,|;|\"|\'|:"; 
	
	
	//Digits
	private static final char LATIN_NINE = '\u0039';
	private static final char LATIN_EIGHT = '\u0038';
	private static final char LATIN_SEVEN = '\u0037';
	private static final char LATIN_SIX = '\u0036';
	private static final char LATIN_FIVE = '\u0035';
	private static final char LATIN_FOUR = '\u0034';
	private static final char LATIN_THREE = '\u0033';
	private static final char LATIN_TWO = '\u0032';
	private static final char LATIN_ONE = '\u0031';
	private static final char LATIN_ZERO = '\u0030';
	private static final char ARABIC_NINE = '\u0669';
	private static final char ARABIC_EIGHT = '\u0668';
	private static final char ARABIC_SEVEN = '\u0667';
	private static final char ARABIC_SIX = '\u0666';
	private static final char ARABIC_FIVE = '\u0665';
	private static final char ARABIC_FOUR = '\u0664';
	private static final char ARABIC_THREE = '\u0663';
	private static final char ARABIC_TWO = '\u0662';
	private static final char ARABIC_ONE = '\u0661';
	private static final char ARABIC_ZERO = '\u0660';
	private static final char FARSI_NINE = '\u06F9';
	private static final char FARSI_EIGHT = '\u06F8';
	private static final char FARSI_SEVEN = '\u06F7';
	private static final char FARSI_SIX = '\u06F6';
	private static final char FARSI_FIVE = '\u06F5';
	private static final char FARSI_FOUR = '\u06F4';
	private static final char FARSI_THREE = '\u06F3';
	private static final char FARSI_TWO = '\u06F2';
	private static final char FARSI_ONE = '\u06F1';
	private static final char FARSI_ZERO = '\u06F0';
	
	//E'era'ab
	private static final char SUPERSCRIBE_ALEF = '\u0670';
	private static final char SUKUN = '\u0650';
	private static final char KASRATAN = '\u064F';
	private static final char DAMMATAN = '\u064C';
	private static final char MEDIAL_KASTA = '\uFE7B';
	private static final char ISOLATED_KASRA_B = '\uFE7A';
	private static final char MEDIAL_DMMA = '\uFE79';
	private static final char ISOLATED_DAMMA_B = '\uFE78';
	private static final char MEDIAL_FATHA = '\uFE77';
	private static final char ISOLATED_FATHA_B = '\uFE76';
	private static final char ISOLATED_KASRA_A = '\u0650';
	private static final char ISOLATED_DAMMA_A = '\u064F';
	private static final char ISOLATED_FATHA_A = '\u064E';

	
	//KAF_YEH
	private static final char FARSI_YEH = '\u06CC';
	private static final char ARABIC_YEH = '\u064A';
	private static final char FARSI_KAF = '\u06A9';
	private static final char ARABIC_KAF = '\u0643';
	
	//Punctuations and Others
	private static final char NULL_CHAR = '\u0000';
	private static final char ARABIC_FARSI_SEMICOLON = '\u061B';
	private static final char ARABIC_FARSI_COMMA = '\u060C';
	

	
	public static HashMap<Character, Character> getKafYehReplacementMap() {
		final HashMap<Character, Character> KAF_YEH_MAP = new HashMap<Character, Character>();
		KAF_YEH_MAP.put(ARABIC_KAF, FARSI_KAF); // Kaf
		KAF_YEH_MAP.put(ARABIC_YEH, FARSI_YEH); // Yeh
		return KAF_YEH_MAP;
	}

	public static HashMap<Character, Character> getPunctuationReplacementMap() {
		final HashMap<Character, Character> PUNCTUATION_MAP = new HashMap<Character, Character>();
		PUNCTUATION_MAP.put(ARABIC_FARSI_COMMA, ARABIC_FARSI_COMMA); // Comma
		PUNCTUATION_MAP.put(ARABIC_FARSI_SEMICOLON, ARABIC_FARSI_SEMICOLON); // Semicolon
		return PUNCTUATION_MAP;
	}

	public static HashMap<Character, Character> getArabicDigitReplacementMap() {

		final HashMap<Character, Character> DIGITS_MAP = new HashMap<Character, Character>();
		DIGITS_MAP.put(ARABIC_ZERO, FARSI_ZERO); // Zero
		DIGITS_MAP.put(ARABIC_ONE, FARSI_ONE); // One
		DIGITS_MAP.put(ARABIC_TWO, FARSI_TWO); // Two
		DIGITS_MAP.put(ARABIC_THREE, FARSI_THREE); // Three
		DIGITS_MAP.put(ARABIC_FOUR, FARSI_FOUR); // Four
		DIGITS_MAP.put(ARABIC_FIVE, FARSI_FIVE); // Five
		DIGITS_MAP.put(ARABIC_SIX, FARSI_SIX); // Six
		DIGITS_MAP.put(ARABIC_SEVEN, FARSI_SEVEN); // Seven
		DIGITS_MAP.put(ARABIC_EIGHT, FARSI_EIGHT); // Eight
		DIGITS_MAP.put(ARABIC_NINE, FARSI_NINE); // Nine

		return DIGITS_MAP;
	}

	public static HashMap<Character, Character> getLatinDigitReplacementMap() {

		final HashMap<Character, Character> DIGITS_MAP = new HashMap<Character, Character>();
		DIGITS_MAP.put(LATIN_ZERO, FARSI_ZERO); // Zero
		DIGITS_MAP.put(LATIN_ONE, FARSI_ONE); // One
		DIGITS_MAP.put(LATIN_TWO, FARSI_TWO); // Two
		DIGITS_MAP.put(LATIN_THREE, FARSI_THREE); // Three
		DIGITS_MAP.put(LATIN_FOUR, FARSI_FOUR); // Four
		DIGITS_MAP.put(LATIN_FIVE, FARSI_FIVE); // Five
		DIGITS_MAP.put(LATIN_SIX, FARSI_SIX); // Six
		DIGITS_MAP.put(LATIN_SEVEN, FARSI_SEVEN); // Seven
		DIGITS_MAP.put(LATIN_EIGHT, FARSI_EIGHT); // Eight
		DIGITS_MAP.put(LATIN_NINE, FARSI_NINE); // Nine

		return DIGITS_MAP;
	}

	public static HashMap<Character, Character> getShortVowelsMap() {

		final HashMap<Character, Character> SHORT_VOWELS_MAP = new HashMap<Character, Character>();
		SHORT_VOWELS_MAP.put(ISOLATED_FATHA_A, NULL_CHAR); 
		SHORT_VOWELS_MAP.put(ISOLATED_DAMMA_A, NULL_CHAR);
		SHORT_VOWELS_MAP.put(ISOLATED_KASRA_A, NULL_CHAR); 

		SHORT_VOWELS_MAP.put(ISOLATED_FATHA_B, NULL_CHAR); 
		SHORT_VOWELS_MAP.put(MEDIAL_FATHA, NULL_CHAR); 
		SHORT_VOWELS_MAP.put(ISOLATED_DAMMA_B, NULL_CHAR); 
		SHORT_VOWELS_MAP.put(MEDIAL_DMMA, NULL_CHAR); 
		SHORT_VOWELS_MAP.put(ISOLATED_KASRA_B, NULL_CHAR);
		SHORT_VOWELS_MAP.put(MEDIAL_KASTA, NULL_CHAR);

		return SHORT_VOWELS_MAP;
	}

	public static HashMap<Character, Character> getFullDeclensionMap() {

		final HashMap<Character, Character> FULL_DECLENSION_MAP = new HashMap<Character, Character>();
		FULL_DECLENSION_MAP.put(DAMMATAN, NULL_CHAR); 
		FULL_DECLENSION_MAP.put(KASRATAN, NULL_CHAR); 
		FULL_DECLENSION_MAP.put(SUKUN, NULL_CHAR);
		FULL_DECLENSION_MAP.put(SUPERSCRIBE_ALEF, NULL_CHAR);

		return FULL_DECLENSION_MAP;
	}

}
