package org.kaveh.commons.farsi.v2.impl;

import java.util.HashMap;
import java.util.Iterator;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

import org.kaveh.commons.farsi.v2.FarsiOps;

public class FarsiOpsImpl implements FarsiOps {

	public String fixArabicString(String inputStringWithPossibleArabicChars) {
		return replaceCharsFromMap(inputStringWithPossibleArabicChars, CharDefenitions.getKafYehReplacementMap());
	}

	public String fixArabicDigits(String inputStringWithPossibleArabicDigits) {
		return replaceCharsFromMap(inputStringWithPossibleArabicDigits, CharDefenitions.getArabicDigitReplacementMap());
	}

	public String fixLatinDigits(String inputStringWithPossibleLatinDigits) {
		return replaceCharsFromMap(inputStringWithPossibleLatinDigits, CharDefenitions.getLatinDigitReplacementMap());
	}

	public String digitsToFarsi(String inputStringWithPossibleLatinOrArabicDigits) {
		return fixLatinDigits(fixArabicDigits(inputStringWithPossibleLatinOrArabicDigits));
	}

	public String declineString(String inputStringWithPossibleDeclensions) {
		return removeCharsFoundInMapKey(inputStringWithPossibleDeclensions, CharDefenitions.getShortVowelsMap());
	}

	public String fullyDecline(String inputStringwithAllDeclensions) {
		return declineString(removeCharsFoundInMapKey(inputStringwithAllDeclensions, CharDefenitions.getFullDeclensionMap()));

	}

	public String farSize(String inputString) {
		return declineString(fixLatinDigits(fixArabicDigits(fixArabicString(inputString))));
	}

	public boolean hasAnyLatin(String inputString) {
		return inputString.matches("^(.*)?[" + CharDefenitions.LATIN_CHARS_RANGE + "](.*)?$");

	}

	public boolean hasOnlyLatin(String inputString) {
		return inputString.matches("^[" + CharDefenitions.LATIN_CHARS_RANGE + CharDefenitions.USUAL_TEXT_ADDITIONS_RANGE + "]*$");
	}

	public boolean hasAnyLatinDigits(String inputString) {
		return inputString.matches("^(.*)?[" + CharDefenitions.LATIN_DIGITS_RANGE + "](.*)?$");
	}

	public boolean hasAnyArabic(String inputString) {
		return inputString.matches("^(.*)?[" + CharDefenitions.ARABIC_CHARS_RANGE + "](.*)?$");
	}

	public boolean hasOnlyArabic(String inputString) {
		return inputString.matches("^[" + CharDefenitions.ARABIC_CHARS_RANGE + CharDefenitions.USUAL_TEXT_ADDITIONS_RANGE + "]*$");
	}

	public boolean hasAnyArabicDigits(String inputString) {
		return inputString.matches("^(.*)?[" + CharDefenitions.ARABIC_DIGITS_RANGE + "](.*)?$");

	}

	public boolean hasAnyFarsi(String inputString) {
		return inputString.matches("^(.*)?[" + CharDefenitions.FARSI_CHARS_RANGE + "](.*)?$");

	}

	public boolean hasOnlyFarsi(String inputString) {
		return inputString.matches("^[" + CharDefenitions.FARSI_CHARS_RANGE + CharDefenitions.USUAL_TEXT_ADDITIONS_RANGE + "]*$");
	}

	public boolean hasAnyFarsiDigits(String inputString) {
		return inputString.matches("^(.*)?[" + CharDefenitions.FARSI_DIGITS_RANGE + "](.*)?$");

	}

	private String replaceCharsFromMap(String inputString, HashMap<Character, Character> inputMap) {
		StringBuilder sb = new StringBuilder(inputString);

		Iterator<Character> iterator = inputMap.keySet().iterator();
		while (iterator.hasNext()) {
			Character key = iterator.next();
			Matcher matcher = Pattern.compile(key.toString()).matcher(sb);
			while (matcher.find())
				sb.replace(matcher.start(), matcher.end(), inputMap.get(key).toString());

		}

		return (sb.toString());
	}

	private String removeCharsFoundInMapKey(String inputString, HashMap<Character, Character> inputMap) {

		Iterator<Character> iterator = inputMap.keySet().iterator();
		String regexp = "^";
		while (iterator.hasNext()) {
			regexp = regexp + iterator.next().toString() + "|";
		}
		regexp = regexp + "$";
		return inputString.replaceAll(regexp, "");

	}

}
